---
name: Documentation
about: Improve the documentation
title: 'Documentation: '
labels: documentation
assignees: k98kurz

---

### Describe the Issue

A clear and concise description of the documentation issue.

### Documentation Files and Sections

- readme.md: "Usage"
- dox.md: "Classes > Entry"

### Discrepancies from Documentation Encountered

A clear and concise description of what discrepancies you found.

### Additional context

Add any other context about the problem here.
